@@ -56,6 +56,7 @@
 
 #include <gtk/gtkversion.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkaccelmap.h>
 
 /*****************************************************************************
  * libgnomeui
@@ -303,10 +304,11 @@ static void
 libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 {
         GnomeProgramPrivate_libgnomeui *priv = g_new0(GnomeProgramPrivate_libgnomeui, 1);
+        gchar *filename;
 
         gnome_type_init();
         /* #warning FIXME: here... gtk_rc ... */
-        libgnomeui_rc_parse (program, program_invocation_name);
+        libgnomeui_rc_parse (program, g_get_prgname ());
 
         libgnomeui_segv_setup (program, TRUE);
 
@@ -314,6 +316,16 @@ libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
         priv->constructed = TRUE;
 
         _gnome_stock_icons_init ();
+
+        /* load the accelerators */
+        filename = g_build_filename (gnome_user_accels_dir_get (),
+                                     gnome_program_get_app_id (program),
+                                     NULL);
+        gtk_accel_map_load (filename);
+        g_free (filename);
+
+	bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
+	//bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 }
 
 static void
@@ -505,11 +517,11 @@ static void libgnomeui_segv_handle(int signum)
 
 		/* Child process */
 		execl (GNOMEUIBINDIR "/gnome_segv2", GNOMEUIBINDIR "/gnome_segv",
-		       program_invocation_name, buf,
+		       g_get_prgname (), buf,
 		       gnome_program_get_app_version (program), NULL);
 
                 execlp ("gnome_segv2", "gnome_segv2",
-			program_invocation_name, buf,
+			g_get_prgname (), buf,
 			gnome_program_get_app_version (program), NULL);
 
                 _exit(99);
